Module structs

Module structs 

Contains the core data structures and types used in the this.env crate.

Structs

Endorsement
Endorser signature and approval status
EnvRequestLog
RouteInfo
Represents metadata and analytics for a specific route within an environment.

Enums

EnvStatus
Represents the endorsement evaluation result for a given environment.
EnvType
Represents the type of environment where an identity operates.
TrustLevel
Represents the level of trust assigned to an environment.