Contains the core data structures and types used in the this.env crate.
Structs
- Endorsement
- Endorser signature and approval status
- EnvRequest
Log - Route
Info - Represents metadata and analytics for a specific route within an environment.
Enums
- EnvStatus
- Represents the endorsement evaluation result for a given environment.
- EnvType
- Represents the type of environment where an identity operates.
- Trust
Level - Represents the level of trust assigned to an environment.